==> blancoMessage-0.5.3-src.zip: blancoMessage/blanco/main/blanco/sample/message/Sample2Message.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.sample.message;

/**
 * bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
 */
public class Sample2Message {
    /**
     * bZ[WvpeBt@CΉ邽߂̓Iɗp郊\[XohNXB
     */
    protected final Sample2MessageResourceBundle fBundle = new Sample2MessageResourceBundle();

    /**
     * [bZ[W̃TvB̂PB]
     *
     * No.1:
     */
    public static final String MESSAGE001 = "[MESSAGE001] bZ[W̃TvB̂PB";

    /**
     * [bZ[Wu[{0}]u܂B]
     *
     * No.2:
     */
    public static final String MESSAGE002 = "[MESSAGE002] bZ[Wu[{0}]u܂B";

    /**
     * [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
     *
     * No.3:
     */
    public static final String MESSAGE003 = "[MESSAGE003] bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B";

    /**
     * [AbZ[Wu{0}{1}̗łB]
     *
     * No.4:
     */
    public static final String MESSAGE004 = "[MESSAGE004] AbZ[Wu{0}{1}̗łB";

    /**
     * [{0}擪u񂪂B]
     *
     * No.5:
     */
    public static final String MESSAGE005 = "[MESSAGE005] {0}擪u񂪂B";

    /**
     * [Ōオu̗B{0}]
     *
     * No.6:
     */
    public static final String MESSAGE006 = "[MESSAGE006] Ōオu̗B{0}";

    /**
     * [xu{0}{1}{0}{1}{2}{1}{0}]
     *
     * No.7:
     */
    public static final String MESSAGE007 = "[MESSAGE007] xu{0}{1}{0}{1}{2}{1}{0}";

    /**
     * [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
     *
     * No.8:
     */
    public static final String MESSAGE008 = "[MESSAGE008] ̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B";

    /**
     * [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]
     *
     * No.9:
     */
    public static final String MESSAGE009 = "[MESSAGE009] {0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB";

    /**
     * [GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]
     *
     * No.10:
     */
    public static final String MESSAGE010 = "[MESSAGE010] GXP[v̊mFB_uNI[e[V\"AVONI[e[V'AG}[N\\B";

    /**
     * [~]
     *
     * No.11:
     */
    public static final String MESSAGE011 = "[MESSAGE011] ~";

    /**
     * [s[\n]̎B]
     *
     * No.12:
     */
    public static final String MESSAGE012 = "[MESSAGE012] s[\n]̎B";

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE001]̕擾܂B
     *
     * No.1:
     * [bZ[W̃TvB̂PB]
     *
     * @return bZ[WB
     */
    public String getMessage001() {
        return "[MESSAGE001] " + fBundle.getMessage001();
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE002]̕擾܂B
     *
     * No.2:
     * [bZ[Wu[{0}]u܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMessage002(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE002] " + fBundle.getMessage002(arg0);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE003]̕擾܂B
     *
     * No.3:
     * [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMessage003(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE003] " + fBundle.getMessage003(arg0, arg1);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE004]̕擾܂B
     *
     * No.4:
     * [AbZ[Wu{0}{1}̗łB]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMessage004(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE004] " + fBundle.getMessage004(arg0, arg1);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE005]̕擾܂B
     *
     * No.5:
     * [{0}擪u񂪂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMessage005(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage005]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE005] " + fBundle.getMessage005(arg0);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE006]̕擾܂B
     *
     * No.6:
     * [Ōオu̗B{0}]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMessage006(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage006]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE006] " + fBundle.getMessage006(arg0);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE007]̕擾܂B
     *
     * No.7:
     * [xu{0}{1}{0}{1}{2}{1}{0}]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @param arg2 u{2}̒lB
     * @return bZ[WB
     */
    public String getMessage007(final String arg0, final String arg1, final String arg2) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage007]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage007]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg2 == null) {
            throw new IllegalArgumentException("\bh[getMessage007]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE007] " + fBundle.getMessage007(arg0, arg1, arg2);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE008]̕擾܂B
     *
     * No.8:
     * [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @param arg2 u{2}̒lB
     * @param arg3 u{3}̒lB
     * @param arg4 u{4}̒lB
     * @param arg5 u{5}̒lB
     * @param arg6 u{6}̒lB
     * @param arg7 u{7}̒lB
     * @param arg8 u{8}̒lB
     * @param arg9 u{9}̒lB
     * @param arg10 u{10}̒lB
     * @param arg11 u{11}̒lB
     * @return bZ[WB
     */
    public String getMessage008(final String arg0, final String arg1, final String arg2, final String arg3, final String arg4, final String arg5, final String arg6, final String arg7, final String arg8, final String arg9, final String arg10, final String arg11) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg2 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg3 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg4 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg4]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg5 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg5]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg6 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg6]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg7 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg7]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg8 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg8]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg9 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg9]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg10 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg10]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg11 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg11]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE008] " + fBundle.getMessage008(arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE009]̕擾܂B
     *
     * No.9:
     * [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMessage009(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage009]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage009]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE009] " + fBundle.getMessage009(arg0, arg1);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE010]̕擾܂B
     *
     * No.10:
     * [GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]
     *
     * @return bZ[WB
     */
    public String getMessage010() {
        return "[MESSAGE010] " + fBundle.getMessage010();
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE011]̕擾܂B
     *
     * No.11:
     * [~]
     *
     * @return bZ[WB
     */
    public String getMessage011() {
        return "[MESSAGE011] " + fBundle.getMessage011();
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE012]̕擾܂B
     *
     * No.12:
     * [s[\n]̎B]
     *
     * @return bZ[WB
     */
    public String getMessage012() {
        return "[MESSAGE012] " + fBundle.getMessage012();
    }
}

==> blancoMessage-0.5.7-src.zip: blancoMessage/blanco/main/blanco/sample/message/Sample2Message.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.sample.message;

/**
 * bZ[W̃TvB̃NX͒PɃTvłBۂ̓ɂ͗p܂B
 */
public class Sample2Message {
    /**
     * bZ[WvpeBt@CΉ邽߂̓Iɗp郊\[XohNXB
     */
    protected final Sample2MessageResourceBundle fBundle = new Sample2MessageResourceBundle();

    /**
     * [bZ[W̃TvB̂PB]
     *
     * No.1:
     */
    public static final String MESSAGE001 = "[MESSAGE001] bZ[W̃TvB̂PB";

    /**
     * L[l: KEY_MESSAGE001
     *
     * No.1:
     */
    public static final String KEY_MESSAGE001 = "MESSAGE001";

    /**
     * [bZ[Wu[{0}]u܂B]
     *
     * No.2:
     */
    public static final String MESSAGE002 = "[MESSAGE002] bZ[Wu[{0}]u܂B";

    /**
     * L[l: KEY_MESSAGE002
     *
     * No.2:
     */
    public static final String KEY_MESSAGE002 = "MESSAGE002";

    /**
     * [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
     *
     * No.3:
     */
    public static final String MESSAGE003 = "[MESSAGE003] bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B";

    /**
     * L[l: KEY_MESSAGE003
     *
     * No.3:
     */
    public static final String KEY_MESSAGE003 = "MESSAGE003";

    /**
     * [AbZ[Wu{0}{1}̗łB]
     *
     * No.4:
     */
    public static final String MESSAGE004 = "[MESSAGE004] AbZ[Wu{0}{1}̗łB";

    /**
     * L[l: KEY_MESSAGE004
     *
     * No.4:
     */
    public static final String KEY_MESSAGE004 = "MESSAGE004";

    /**
     * [{0}擪u񂪂B]
     *
     * No.5:
     */
    public static final String MESSAGE005 = "[MESSAGE005] {0}擪u񂪂B";

    /**
     * L[l: KEY_MESSAGE005
     *
     * No.5:
     */
    public static final String KEY_MESSAGE005 = "MESSAGE005";

    /**
     * [Ōオu̗B{0}]
     *
     * No.6:
     */
    public static final String MESSAGE006 = "[MESSAGE006] Ōオu̗B{0}";

    /**
     * L[l: KEY_MESSAGE006
     *
     * No.6:
     */
    public static final String KEY_MESSAGE006 = "MESSAGE006";

    /**
     * [xu{0}{1}{0}{1}{2}{1}{0}]
     *
     * No.7:
     */
    public static final String MESSAGE007 = "[MESSAGE007] xu{0}{1}{0}{1}{2}{1}{0}";

    /**
     * L[l: KEY_MESSAGE007
     *
     * No.7:
     */
    public static final String KEY_MESSAGE007 = "MESSAGE007";

    /**
     * [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
     *
     * No.8:
     */
    public static final String MESSAGE008 = "[MESSAGE008] ̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B";

    /**
     * L[l: KEY_MESSAGE008
     *
     * No.8:
     */
    public static final String KEY_MESSAGE008 = "MESSAGE008";

    /**
     * [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]
     *
     * No.9:
     */
    public static final String MESSAGE009 = "[MESSAGE009] {0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB";

    /**
     * L[l: KEY_MESSAGE009
     *
     * No.9:
     */
    public static final String KEY_MESSAGE009 = "MESSAGE009";

    /**
     * [GXP[v̊mFB_uNI[e[V&amp;quot;AVONI[e[V'AG}[N\B]
     *
     * No.10:
     */
    public static final String MESSAGE010 = "[MESSAGE010] GXP[v̊mFB_uNI[e[V\"AVONI[e[V'AG}[N\\B";

    /**
     * L[l: KEY_MESSAGE010
     *
     * No.10:
     */
    public static final String KEY_MESSAGE010 = "MESSAGE010";

    /**
     * [~]
     *
     * No.11:
     */
    public static final String MESSAGE011 = "[MESSAGE011] ~";

    /**
     * L[l: KEY_MESSAGE011
     *
     * No.11:
     */
    public static final String KEY_MESSAGE011 = "MESSAGE011";

    /**
     * [s[\n]̎B]
     *
     * No.12:
     */
    public static final String MESSAGE012 = "[MESSAGE012] s[\n]̎B";

    /**
     * L[l: KEY_MESSAGE012
     *
     * No.12:
     */
    public static final String KEY_MESSAGE012 = "MESSAGE012";

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE001]̕擾܂B
     *
     * No.1:
     * [bZ[W̃TvB̂PB]
     *
     * @return bZ[WB
     */
    public String getMessage001() {
        return "[MESSAGE001] " + fBundle.getMessage001();
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE002]̕擾܂B
     *
     * No.2:
     * [bZ[Wu[{0}]u܂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMessage002(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage002]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE002] " + fBundle.getMessage002(arg0);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE003]̕擾܂B
     *
     * No.3:
     * [bZ[Wu[{0}]ɉAЂƂ[{1}]u܂B]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMessage003(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage003]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage003]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE003] " + fBundle.getMessage003(arg0, arg1);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE004]̕擾܂B
     *
     * No.4:
     * [AbZ[Wu{0}{1}̗łB]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMessage004(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage004]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage004]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE004] " + fBundle.getMessage004(arg0, arg1);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE005]̕擾܂B
     *
     * No.5:
     * [{0}擪u񂪂B]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMessage005(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage005]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE005] " + fBundle.getMessage005(arg0);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE006]̕擾܂B
     *
     * No.6:
     * [Ōオu̗B{0}]
     *
     * @param arg0 u{0}̒lB
     * @return bZ[WB
     */
    public String getMessage006(final String arg0) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage006]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE006] " + fBundle.getMessage006(arg0);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE007]̕擾܂B
     *
     * No.7:
     * [xu{0}{1}{0}{1}{2}{1}{0}]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @param arg2 u{2}̒lB
     * @return bZ[WB
     */
    public String getMessage007(final String arg0, final String arg1, final String arg2) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage007]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage007]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg2 == null) {
            throw new IllegalArgumentException("\bh[getMessage007]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE007] " + fBundle.getMessage007(arg0, arg1, arg2);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE008]̕擾܂B
     *
     * No.8:
     * [̒uB{11}{10}{9}{8}{7}{6}{5}{4}{3}{2}{1}{0}12B]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @param arg2 u{2}̒lB
     * @param arg3 u{3}̒lB
     * @param arg4 u{4}̒lB
     * @param arg5 u{5}̒lB
     * @param arg6 u{6}̒lB
     * @param arg7 u{7}̒lB
     * @param arg8 u{8}̒lB
     * @param arg9 u{9}̒lB
     * @param arg10 u{10}̒lB
     * @param arg11 u{11}̒lB
     * @return bZ[WB
     */
    public String getMessage008(final String arg0, final String arg1, final String arg2, final String arg3, final String arg4, final String arg5, final String arg6, final String arg7, final String arg8, final String arg9, final String arg10, final String arg11) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg2 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg2]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg3 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg3]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg4 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg4]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg5 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg5]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg6 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg6]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg7 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg7]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg8 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg8]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg9 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg9]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg10 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg10]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg11 == null) {
            throw new IllegalArgumentException("\bh[getMessage008]̃p[^[arg11]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE008] " + fBundle.getMessage008(arg0, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10, arg11);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE009]̕擾܂B
     *
     * No.9:
     * [{0}ԍԂƒu͕sƂĔf܂B{1}B̒`0IWłB]
     *
     * @param arg0 u{0}̒lB
     * @param arg1 u{1}̒lB
     * @return bZ[WB
     */
    public String getMessage009(final String arg0, final String arg1) {
        if (arg0 == null) {
            throw new IllegalArgumentException("\bh[getMessage009]̃p[^[arg0]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }
        if (arg1 == null) {
            throw new IllegalArgumentException("\bh[getMessage009]̃p[^[arg1]null^܂BÃp[^null^邱Ƃ͂ł܂B");
        }

        return "[MESSAGE009] " + fBundle.getMessage009(arg0, arg1);
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE010]̕擾܂B
     *
     * No.10:
     * [GXP[v̊mFB_uNI[e[V&quot;AVONI[e[V'AG}[N\B]
     *
     * @return bZ[WB
     */
    public String getMessage010() {
        return "[MESSAGE010] " + fBundle.getMessage010();
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE011]̕擾܂B
     *
     * No.11:
     * [~]
     *
     * @return bZ[WB
     */
    public String getMessage011() {
        return "[MESSAGE011] " + fBundle.getMessage011();
    }

    /**
     * bZ[W`ID[Sample2]AL[[MESSAGE012]̕擾܂B
     *
     * No.12:
     * [s[\n]̎B]
     *
     * @return bZ[WB
     */
    public String getMessage012() {
        return "[MESSAGE012] " + fBundle.getMessage012();
    }
}
